@@ -163,14 +163,16 @@ class Sending:
         file_name = pathlib.Path(path).name
         content_type = mimetypes.guess_type(file_name)[0]
 
-        files = {"file": (file_name, open(path, "rb"), content_type)}
-
-        return self.api.request(
-            "POST", (
-                "{{media}}/waInstance{{idInstance}}/"
-                "uploadFile/{{apiTokenInstance}}"
-            ), files=files
-        )
+        with open(path, "rb") as file:
+            return self.api.raw_request(
+                method="POST",
+                url=(
+                    f"{self.api.media}/waInstance{self.api.idInstance}/"
+                    f"uploadFile/{self.api.apiTokenInstance}"
+                ),
+                data=file.read(),
+                headers={"Content-Type": content_type}
+            )
 
     def sendLocation(
             self,
@@ -251,6 +253,28 @@ class Sending:
             ), request_body
         )
 
+    def sendPoll(
+            self,
+            chatId: str,
+            message: str,
+            options: List[Dict[str, str]],
+            multipleAnswers: Optional[bool] = None,
+            quotedMessageId: Optional[str] = None
+    ) -> Response:
+        """
+        This method is intended for sending messages with a poll to a
+        private or group chat.
+        """
+
+        request_body = self.__handle_parameters(locals())
+
+        return self.api.request(
+            "POST", (
+                "{{host}}/waInstance{{idInstance}}/"
+                "sendPoll/{{apiTokenInstance}}"
+            ), request_body
+        )
+
     @classmethod
     def __handle_parameters(cls, parameters: dict) -> dict:
         handled_parameters = parameters.copy()
